## 1.1.0 - 2024-10-29

### Added

- [#1153](https://github.com/edgarrmondragon/citric/issues/1153) Added `name` and `description` parameters to `import_group` RPC method
- [#1190](https://github.com/edgarrmondragon/citric/issues/1190) Added a new `RESTClient` method to refresh the session token
- [#1201](https://github.com/edgarrmondragon/citric/issues/1201) Official support for Python 3.13

### Refactored

- [#1189](https://github.com/edgarrmondragon/citric/issues/1189) Test and document new top-level question attributes from LimeSurvey 6.6.3+

### Documentation

- [#1199](https://github.com/edgarrmondragon/citric/issues/1199) Updated the contributing guide to reflect current workflow
